==> utopia-documents_2.4.2.orig.tar.bz2: utopia-documents-2.4.2/libutopia2/utopia2/pluginmanager_p.h <==
/*****************************************************************************
 *  
 *   This file is part of the Utopia Documents application.
 *       Copyright (c) 2008-2014 Lost Island Labs
 *   
 *   Utopia Documents is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU GENERAL PUBLIC LICENSE VERSION 3 as
 *   published by the Free Software Foundation.
 *   
 *   Utopia Documents is distributed in the hope that it will be useful, but
 *   WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 *   Public License for more details.
 *   
 *   In addition, as a special exception, the copyright holders give
 *   permission to link the code of portions of this program with the OpenSSL
 *   library under certain conditions as described in each individual source
 *   file, and distribute linked combinations including the two.
 *   
 *   You must obey the GNU General Public License in all respects for all of
 *   the code used other than OpenSSL. If you modify file(s) with this
 *   exception, you may extend this exception to your version of the file(s),
 *   but you are not obligated to do so. If you do not wish to do so, delete
 *   this exception statement from your version.
 *   
 *   You should have received a copy of the GNU General Public License
 *   along with Utopia Documents. If not, see <http://www.gnu.org/licenses/>
 *  
 *****************************************************************************/

#ifndef UTOPIA_PLUGINMANAGER_P_H
#define UTOPIA_PLUGINMANAGER_P_H

#include <utopia2/plugin.h>

#include <QMap>
#include <QObject>
#include <QPair>
#include <QUuid>

namespace Utopia
{

    class PluginManager;
    class PluginManagerPrivate : public QObject
    {
        Q_OBJECT

    public:
        PluginManagerPrivate(PluginManager * manager);
        ~PluginManagerPrivate();

        PluginManager * manager;

        QMap< QUuid, Plugin * > pluginsByUuid;
        QMap< QPair< Plugin::PluginBase, QString >, Plugin * > pluginsByPath;

        void load();
        void save();
    };

}

#endif // UTOPIA_PLUGINMANAGER_P_H

==> utopia-documents_3.0.0.orig.tar.bz2: utopia-documents-3.0.0/libutopia2/utopia2/pluginmanager_p.h <==
/*****************************************************************************
 *  
 *   This file is part of the Utopia Documents application.
 *       Copyright (c) 2008-2016 Lost Island Labs
 *           <info@utopiadocs.com>
 *   
 *   Utopia Documents is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU GENERAL PUBLIC LICENSE VERSION 3 as
 *   published by the Free Software Foundation.
 *   
 *   Utopia Documents is distributed in the hope that it will be useful, but
 *   WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 *   Public License for more details.
 *   
 *   In addition, as a special exception, the copyright holders give
 *   permission to link the code of portions of this program with the OpenSSL
 *   library under certain conditions as described in each individual source
 *   file, and distribute linked combinations including the two.
 *   
 *   You must obey the GNU General Public License in all respects for all of
 *   the code used other than OpenSSL. If you modify file(s) with this
 *   exception, you may extend this exception to your version of the file(s),
 *   but you are not obligated to do so. If you do not wish to do so, delete
 *   this exception statement from your version.
 *   
 *   You should have received a copy of the GNU General Public License
 *   along with Utopia Documents. If not, see <http://www.gnu.org/licenses/>
 *  
 *****************************************************************************/

#ifndef UTOPIA_PLUGINMANAGER_P_H
#define UTOPIA_PLUGINMANAGER_P_H

#include <utopia2/plugin.h>

#include <QFileInfo>
#include <QMap>
#include <QObject>
#include <QPair>
#include <QUuid>

namespace Utopia
{

    class PluginManager;
    class PluginManagerPrivate : public QObject
    {
        Q_OBJECT

    public:
        PluginManagerPrivate(PluginManager * manager);
        ~PluginManagerPrivate();

        PluginManager * manager;

        QMap< QUuid, Plugin * > pluginsByUuid;
        QMap< QString, Plugin * > pluginsByPath;

        void load();
        void save();
    };

}

#endif // UTOPIA_PLUGINMANAGER_P_H
